from setuptools import setup, find_packages

setup(
    name='setup_django_apex',
    version='0.1.1',
    packages=find_packages(),
    entry_points={
        'console_scripts': [
            'setup-django-apex = setup_django_apex.installer:main',
        ],
    },
)



import unittest
import os
import shutil
from setup_django_apex.installer import create_django_project, create_django_app, update_settings

class TestInstaller(unittest.TestCase):
    @classmethod
    def setUpClass(cls):
        cls.project_name = 'testproject'
        cls.app_names = ['app1', 'app2']
        create_django_project(cls.project_name)
        os.chdir(cls.project_name)

    @classmethod
    def tearDownClass(cls):
        os.chdir('..')
        shutil.rmtree(cls.project_name)

    def test_create_django_app(self):
        for app_name in self.app_names:
            create_django_app(app_name)
            self.assertTrue(os.path.isdir(app_name))
            self.assertTrue(os.path.isfile(os.path.join(app_name, 'views.py')))

    def test_update_settings(self):
        update_settings(self.app_names, self.project_name)
        settings_path = os.path.join(self.project_name, 'settings.py')
        with open(settings_path, 'r') as file:
            settings_content = file.read()
            for app_name in self.app_names:
                self.assertIn(f"'{app_name}'", settings_content)

if __name__ == '__main__':
    unittest.main()



import os
import subprocess
import unittest
import sys
sys.path.append("c:\\Users\\omani\\OneDrive\\Documents\\django_pip")
from setup_django_apex.installer import create_django_project, create_django_app, update_settings
class TestInstaller(unittest.TestCase):
    def setUp(self):
        # Set up any resources needed for the tests
        self.project_name = "test_project"

    # def tearDown(self):
    #     # Clean up resources after each test
    #     if os.path.exists(self.project_name):
    #         subprocess.run(f"rm -rf {self.project_name}", shell=True)

    def test_create_django_project(self):
        # Test creating a Django project
        if not os.path.exists(self.project_name):
            create_django_project(self.project_name)
            self.assertTrue(os.path.isdir(self.project_name))

    # def test_create_django_app(self):
    #     # Test creating a Django app
    #     if not os.path.exists(self.project_name):
    #         create_django_project(self.project_name)  # Ensure project is created first
    #     create_django_app("test_app")
    #     app_dir = os.path.join(self.project_name, "test_app")
    #     self.assertTrue(os.path.isdir(app_dir))
    #     self.assertTrue(os.path.isfile(os.path.join(app_dir, "views.py")))

    def test_update_settings(self):
        # Test updating settings.py
        app_names = ["app1", "app2"]
        if not os.path.exists(self.project_name):
            (self.project_name)  # Ensure project is created first
        
        for app_name in app_names:
            create_django_app(app_name)  # Ensure all required apps are created
        # create_django_app("test_app")  # Ensure at least one app is created
        update_settings(app_names, self.project_name)
        settings_path = os.path.join(self.project_name, "settings.py")
        with open(settings_path, "r") as file:
            settings_content = file.read()
        for app_name in app_names:
            self.assertIn(f"'{app_name}'", settings_content)

if __name__ == "__main__":
    unittest.main()



from setuptools import setup, find_packages
from setuptools.command.install import install
import subprocess

class CustomInstallCommand(install):
    def run(self):
        install.run(self)
        subprocess.check_call(['python', '-m', 'setup_django_apex.installer'])

setup(
    name='setup_django_apex',
    version='0.1.1',
    author='Anirudha Udgirkar',
    author_email='anirudhaudgirkar.work.email@example.com',
    description='A library to set up Django projects with multiple apps',
    long_description=open('README.md').read(),
    long_description_content_type='text/markdown',
    url='https://github.com/Anirudha1821/setup_django_apex',
    packages=find_packages(),
    classifiers=[
        'Programming Language :: Python :: 3',
        'License :: OSI Approved :: MIT License',
        'Operating System :: OS Independent',
    ],
    python_requires='>=3.6',
    install_requires=[
        'Django>=3.0',
        'django>=3.0',
    ], 
    extras_require={
        'tests': ['pytest'],
    },
    cmdclass={
        'install': CustomInstallCommand,
    },
)



import os
import subprocess

def run_command(command):
    process = subprocess.Popen(command, shell=True, stdout=subprocess.PIPE, stderr=subprocess.PIPE)
    stdout, stderr = process.communicate()
    if process.returncode != 0:
        raise Exception(f"Command failed with error: {stderr.decode('utf-8')}")
    return stdout.decode('utf-8')

def create_django_project(project_name):
    run_command(f'django-admin startproject {project_name}')
    os.chdir(project_name)

def create_django_app(app_name):
    run_command(f'python manage.py startapp {app_name}')

def update_settings(app_names, project_name):
    settings_path = os.path.join(project_name, 'settings.py')
    with open(settings_path, 'r') as file:
        settings = file.readlines()

    installed_apps_index = None
    for i, line in enumerate(settings):
        if line.strip() == 'INSTALLED_APPS = [':
            installed_apps_index = i
            break

    if installed_apps_index is None:
        raise Exception("Couldn't find INSTALLED_APPS in settings.py")

    for app_name in app_names:
        app_entry = f"    '{app_name}',\n"
        if app_entry not in settings:
            settings.insert(installed_apps_index + 1, app_entry)

    with open(settings_path, 'w') as file:
        file.writelines(settings)

def main():
    project_name = input("Enter the name of your Django project: ")
    create_django_project(project_name)

    num_apps = int(input("How many apps do you want to create? "))
    app_names = []
    for _ in range(num_apps):
        app_name = input("Enter the name of the app: ")
        create_django_app(app_name)
        app_names.append(app_name)

    update_settings(app_names, project_name)
    print(f"Successfully created project {project_name} with apps: {', '.join(app_names)}")

if __name__ == "__main__":
    main()
